﻿using System;
using System.Collections.Generic;
using System.Text;
using IDAL;
using Model;
using System.Data;
using System.Data.OracleClient;
using DBUtility;

namespace OracleDAL
{
    public class Contact : IContact
    {

        // Static constants
        private const string SQL_SELECT_CONTACTS =
            "SELECT Id, Name, Phone FROM Contact";

        private const string SQL_SELECT_CONTACT =
            @"SELECT Id, Name, Phone FROM Contact 
            WHERE Id = :Id";

        private const string PARM_CONTACT_ID =
            ":Id";

        public IList<ContactInfo> GetContacts()
        {
            IList<ContactInfo> contacts =
                new List<ContactInfo>();

            using (OracleDataReader rdr =
                OracleHelper.ExecuteReader(OracleHelper.ConnectionString,
                CommandType.TableDirect, "Contact", null))
            {
                while (rdr.Read())
                {
                    ContactInfo contact =
                        new ContactInfo(rdr.GetInt32(0).ToString(),
                            rdr.GetString(1), rdr.GetString(2));
                    contacts.Add(contact);
                }
            }
            return contacts;
        }

        public ContactInfo GetContact(string contactId)
        {

            ContactInfo contact = null;

            OracleParameter parm =
                new OracleParameter(PARM_CONTACT_ID,
                    SqlDbType.Int);
            parm.Value = Convert.ToInt32(contactId);

            using (OracleDataReader rdr =
                OracleHelper.ExecuteReader(SqlHelper.ConnectionString,
                CommandType.Text, SQL_SELECT_CONTACT, parm))
            {
                if (rdr.Read())
                    contact = new ContactInfo(
                        rdr.GetInt32(0).ToString(),
                        rdr.GetString(1),
                        rdr.GetString(2));
                else
                    contact = new ContactInfo();
            }
            return contact;
        }

        public static OracleCommand GetCommand()
        {
            return new OracleCommand(SQL_SELECT_CONTACTS);
        }
    }
}
